==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ExtractionLinksType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ExtractionLinksType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ExtractionLinksType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseExtractionType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="text" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="fromText" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/all&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExtractionLinksType", propOrder = {
    "text"
})
public class ExtractionLinksType
    extends BaseExtractionType
{

    protected ExtractionLinksType.Text text;

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link ExtractionLinksType.Text }
     *     
     */
    public ExtractionLinksType.Text getText() {
        return text;
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtractionLinksType.Text }
     *     
     */
    public void setText(ExtractionLinksType.Text value) {
        this.text = value;
    }

    public boolean isSetText() {
        return (this.text!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="fromText" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Text {

        @XmlAttribute(name = "fromText")
        protected Boolean fromText;

        /**
         * Gets the value of the fromText property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isFromText() {
            if (fromText == null) {
                return false;
            } else {
                return fromText;
            }
        }

        /**
         * Sets the value of the fromText property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setFromText(boolean value) {
            this.fromText = value;
        }

        public boolean isSetFromText() {
            return (this.fromText!= null);
        }

        public void unsetFromText() {
            this.fromText = null;
        }

    }

}

==> webpdf-wsclient-2.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ExtractionLinksType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ExtractionLinksType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ExtractionLinksType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseExtractionType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="text" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;attribute name="fromText" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *                 &lt;attribute name="protocol" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
 *                 &lt;attribute name="withoutProtocol" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/all&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExtractionLinksType", propOrder = {
    "text"
})
public class ExtractionLinksType
    extends BaseExtractionType
{

    protected ExtractionLinksType.Text text;

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link ExtractionLinksType.Text }
     *     
     */
    public ExtractionLinksType.Text getText() {
        return text;
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtractionLinksType.Text }
     *     
     */
    public void setText(ExtractionLinksType.Text value) {
        this.text = value;
    }

    public boolean isSetText() {
        return (this.text!= null);
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;attribute name="fromText" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
     *       &lt;attribute name="protocol" type="{http://www.w3.org/2001/XMLSchema}string" default="" /&gt;
     *       &lt;attribute name="withoutProtocol" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class Text {

        @XmlAttribute(name = "fromText")
        protected Boolean fromText;
        @XmlAttribute(name = "protocol")
        protected String protocol;
        @XmlAttribute(name = "withoutProtocol")
        protected Boolean withoutProtocol;

        /**
         * Gets the value of the fromText property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isFromText() {
            if (fromText == null) {
                return false;
            } else {
                return fromText;
            }
        }

        /**
         * Sets the value of the fromText property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setFromText(boolean value) {
            this.fromText = value;
        }

        public boolean isSetFromText() {
            return (this.fromText!= null);
        }

        public void unsetFromText() {
            this.fromText = null;
        }

        /**
         * Gets the value of the protocol property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getProtocol() {
            if (protocol == null) {
                return "";
            } else {
                return protocol;
            }
        }

        /**
         * Sets the value of the protocol property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setProtocol(String value) {
            this.protocol = value;
        }

        public boolean isSetProtocol() {
            return (this.protocol!= null);
        }

        /**
         * Gets the value of the withoutProtocol property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isWithoutProtocol() {
            if (withoutProtocol == null) {
                return true;
            } else {
                return withoutProtocol;
            }
        }

        /**
         * Sets the value of the withoutProtocol property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setWithoutProtocol(boolean value) {
            this.withoutProtocol = value;
        }

        public boolean isSetWithoutProtocol() {
            return (this.withoutProtocol!= null);
        }

        public void unsetWithoutProtocol() {
            this.withoutProtocol = null;
        }

    }

}
